@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,10 +20,10 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.api_core import operation  # type: ignore
@@ -33,18 +31,16 @@ from google.api_core import operation_async  # type: ignore
 from google.cloud.managedidentities_v1.services.managed_identities_service import pagers
 from google.cloud.managedidentities_v1.types import managed_identities_service
 from google.cloud.managedidentities_v1.types import resource
-from google.protobuf import empty_pb2 as empty  # type: ignore
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import ManagedIdentitiesServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import ManagedIdentitiesServiceGrpcAsyncIOTransport
 from .client import ManagedIdentitiesServiceClient
 
 
 class ManagedIdentitiesServiceAsyncClient:
-    """
-    API Overview
+    """API Overview
 
     The ``managedidentites.googleapis.com`` service implements the
     Google Cloud Managed Identites API for identity services (e.g.
@@ -88,33 +84,28 @@ class ManagedIdentitiesServiceAsyncClient:
 
     domain_path = staticmethod(ManagedIdentitiesServiceClient.domain_path)
     parse_domain_path = staticmethod(ManagedIdentitiesServiceClient.parse_domain_path)
-
     common_billing_account_path = staticmethod(
         ManagedIdentitiesServiceClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         ManagedIdentitiesServiceClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(ManagedIdentitiesServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         ManagedIdentitiesServiceClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         ManagedIdentitiesServiceClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         ManagedIdentitiesServiceClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(
         ManagedIdentitiesServiceClient.common_project_path
     )
     parse_common_project_path = staticmethod(
         ManagedIdentitiesServiceClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(
         ManagedIdentitiesServiceClient.common_location_path
     )
@@ -124,7 +115,8 @@ class ManagedIdentitiesServiceAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -139,7 +131,7 @@ class ManagedIdentitiesServiceAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -156,7 +148,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
     @property
     def transport(self) -> ManagedIdentitiesServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             ManagedIdentitiesServiceTransport: The transport used by the client instance.
@@ -171,12 +163,12 @@ class ManagedIdentitiesServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, ManagedIdentitiesServiceTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the managed identities service client.
+        """Instantiates the managed identities service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -208,7 +200,6 @@ class ManagedIdentitiesServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = ManagedIdentitiesServiceClient(
             credentials=credentials,
             transport=transport,
@@ -266,7 +257,6 @@ class ManagedIdentitiesServiceAsyncClient:
                 This corresponds to the ``domain`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -296,7 +286,6 @@ class ManagedIdentitiesServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if domain_name is not None:
@@ -354,7 +343,6 @@ class ManagedIdentitiesServiceAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -381,7 +369,6 @@ class ManagedIdentitiesServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -427,7 +414,6 @@ class ManagedIdentitiesServiceAsyncClient:
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -457,7 +443,6 @@ class ManagedIdentitiesServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -509,7 +494,6 @@ class ManagedIdentitiesServiceAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -536,7 +520,6 @@ class ManagedIdentitiesServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -565,7 +548,7 @@ class ManagedIdentitiesServiceAsyncClient:
         request: managed_identities_service.UpdateDomainRequest = None,
         *,
         domain: resource.Domain = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -596,7 +579,6 @@ class ManagedIdentitiesServiceAsyncClient:
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -626,7 +608,6 @@ class ManagedIdentitiesServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if domain is not None:
             request.domain = domain
         if update_mask is not None:
@@ -684,7 +665,6 @@ class ManagedIdentitiesServiceAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -724,7 +704,6 @@ class ManagedIdentitiesServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -749,7 +728,7 @@ class ManagedIdentitiesServiceAsyncClient:
         response = operation_async.from_gapic(
             response,
             self._client._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=managed_identities_service.OpMetadata,
         )
 
@@ -785,7 +764,6 @@ class ManagedIdentitiesServiceAsyncClient:
                 This corresponds to the ``trust`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -815,7 +793,6 @@ class ManagedIdentitiesServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
         if trust is not None:
@@ -890,7 +867,6 @@ class ManagedIdentitiesServiceAsyncClient:
                 This corresponds to the ``target_dns_ip_addresses`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -920,12 +896,10 @@ class ManagedIdentitiesServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
         if target_domain_name is not None:
             request.target_domain_name = target_domain_name
-
         if target_dns_ip_addresses:
             request.target_dns_ip_addresses.extend(target_dns_ip_addresses)
 
@@ -988,7 +962,6 @@ class ManagedIdentitiesServiceAsyncClient:
                 This corresponds to the ``trust`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1018,7 +991,6 @@ class ManagedIdentitiesServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
         if trust is not None:
@@ -1085,7 +1057,6 @@ class ManagedIdentitiesServiceAsyncClient:
                 This corresponds to the ``trust`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1115,7 +1086,6 @@ class ManagedIdentitiesServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
         if trust is not None:
