@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,13 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.managedidentities_v1.types import resource
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -45,7 +42,6 @@ __protobuf__ = proto.module(
 
 class OpMetadata(proto.Message):
     r"""Represents the metadata of the long-running operation.
-
     Attributes:
         create_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The time the operation was
@@ -70,17 +66,12 @@ class OpMetadata(proto.Message):
             operation.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp.Timestamp,)
-
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp.Timestamp,)
-
-    target = proto.Field(proto.STRING, number=3)
-
-    verb = proto.Field(proto.STRING, number=4)
-
-    requested_cancellation = proto.Field(proto.BOOL, number=5)
-
-    api_version = proto.Field(proto.STRING, number=6)
+    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
+    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    target = proto.Field(proto.STRING, number=3,)
+    verb = proto.Field(proto.STRING, number=4,)
+    requested_cancellation = proto.Field(proto.BOOL, number=5,)
+    api_version = proto.Field(proto.STRING, number=6,)
 
 
 class CreateMicrosoftAdDomainRequest(proto.Message):
@@ -110,10 +101,8 @@ class CreateMicrosoftAdDomainRequest(proto.Message):
             Required. A Managed Identity domain resource.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    domain_name = proto.Field(proto.STRING, number=2)
-
+    parent = proto.Field(proto.STRING, number=1,)
+    domain_name = proto.Field(proto.STRING, number=2,)
     domain = proto.Field(proto.MESSAGE, number=3, message=resource.Domain,)
 
 
@@ -127,7 +116,7 @@ class ResetAdminPasswordRequest(proto.Message):
             ``projects/{project_id}/locations/global/domains/{domain_name}``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ResetAdminPasswordResponse(proto.Message):
@@ -141,7 +130,7 @@ class ResetAdminPasswordResponse(proto.Message):
             more information.
     """
 
-    password = proto.Field(proto.STRING, number=1)
+    password = proto.Field(proto.STRING, number=1,)
 
 
 class ListDomainsRequest(proto.Message):
@@ -172,15 +161,11 @@ class ListDomainsRequest(proto.Message):
             for more information.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
-
-    filter = proto.Field(proto.STRING, number=4)
-
-    order_by = proto.Field(proto.STRING, number=5)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
+    filter = proto.Field(proto.STRING, number=4,)
+    order_by = proto.Field(proto.STRING, number=5,)
 
 
 class ListDomainsResponse(proto.Message):
@@ -205,10 +190,8 @@ class ListDomainsResponse(proto.Message):
         return self
 
     domains = proto.RepeatedField(proto.MESSAGE, number=1, message=resource.Domain,)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
-
-    unreachable = proto.RepeatedField(proto.STRING, number=3)
+    next_page_token = proto.Field(proto.STRING, number=2,)
+    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class GetDomainRequest(proto.Message):
@@ -221,7 +204,7 @@ class GetDomainRequest(proto.Message):
             ``projects/{project_id}/locations/global/domains/{domain_name}``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class UpdateDomainRequest(proto.Message):
@@ -243,8 +226,9 @@ class UpdateDomainRequest(proto.Message):
             fields specified in update_mask are updated.
     """
 
-    update_mask = proto.Field(proto.MESSAGE, number=1, message=field_mask.FieldMask,)
-
+    update_mask = proto.Field(
+        proto.MESSAGE, number=1, message=field_mask_pb2.FieldMask,
+    )
     domain = proto.Field(proto.MESSAGE, number=2, message=resource.Domain,)
 
 
@@ -258,7 +242,7 @@ class DeleteDomainRequest(proto.Message):
             ``projects/{project_id}/locations/global/domains/{domain_name}``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class AttachTrustRequest(proto.Message):
@@ -274,8 +258,7 @@ class AttachTrustRequest(proto.Message):
             Required. The domain trust resource.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     trust = proto.Field(proto.MESSAGE, number=2, message=resource.Trust,)
 
 
@@ -297,11 +280,9 @@ class ReconfigureTrustRequest(proto.Message):
             trust.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    target_domain_name = proto.Field(proto.STRING, number=2)
-
-    target_dns_ip_addresses = proto.RepeatedField(proto.STRING, number=3)
+    name = proto.Field(proto.STRING, number=1,)
+    target_domain_name = proto.Field(proto.STRING, number=2,)
+    target_dns_ip_addresses = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class DetachTrustRequest(proto.Message):
@@ -318,8 +299,7 @@ class DetachTrustRequest(proto.Message):
             removed.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     trust = proto.Field(proto.MESSAGE, number=2, message=resource.Trust,)
 
 
@@ -337,8 +317,7 @@ class ValidateTrustRequest(proto.Message):
             state for.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     trust = proto.Field(proto.MESSAGE, number=2, message=resource.Trust,)
 
 
